==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sv-SE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Den här användaren kan logga in',
    'activated_disabled_help_text' => 'Du kan inte redigera aktiveringsstatus för ditt eget konto.',
    'assets_user'       => 'Tillgångar tilldelade :name',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos :user_count användare. Observera att du inte kan ändra dina egna användarattribut med hjälp av det här formuläret utan du måste göra ändringar till din egen användare enskilt.',
    'bulk_update_help'	=> 'Det här formuläret låter dig uppdatera flera användare samtidigt. Fyll i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'current_assets'    => 'Tillgångar utcheckade till denna användare',
    'clone'             => 'Kopiera användare',
    'contact_user'      => 'Kontakta :name',
    'edit'              => 'Redigera användare',
    'filetype_info'     => 'Tillåtna filtyper är png, gif, jpg, jpeg, doc, docx, pdf, txt, zip och rar.',
    'history_user'      => 'Historik för :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicka här för att återställa dem.',
    'last_login'        => 'Senaste inloggning',
    'ldap_config_text'  => 'LDAP-konfigurationsinställningar återfinnes under Admin > Inställningar. Den (valfria) valda platsen kommer att ställas in för alla importerade användare.',
    'print_assigned'    => 'Skriv ut alla tilldelade',
    'email_assigned'    => 'E-postlista med alla tilldelade',
    'user_notified'     => 'Användaren har blivit e-postad med en lista över sina nuvarande tilldelade objekt.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inkludera denna användare när du automatiskt tilldelar kvalificerade licenser',
    'auto_assign_help'  => 'Hoppa över denna användare i automatisk tilldelning av licenser',
    'software_user'     => 'Programvara utcheckad till :name',
    'send_email_help'   => 'Du måste ange en e-postadress till användaren för att kunna skicka inloggningsuppgifterna. Utskick av inloggningsuppgifter kan endast göras när användaren skapas. Lösenorden lagras i en one-way hash och kan inte hämtas när de väl sparats.',
    'view_user'         => 'Visa användare :name',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dina nuvarande administratörsinställningar tillåter selektiv tillämpning av tvåfaktorsautentisering.  ',
    'two_factor_enrolled' => '2FA-enhet konfigurerad ',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Användaren kan inte logga in',
    'user_activated'  => 'Användaren kan logga in',
    'activation_status_warning' => 'Ändra inte aktiveringsstatus',
    'group_memberships_helpblock' => 'Endast huvudanvändare kan redigera gruppmedlemskap.',
    'superadmin_permission_warning' => 'Endast huvudanvändare kan ge en användare huvudanvändaråtkomst.',
    'admin_permission_warning' => 'Endast användare med administratörsrättigheter eller högre kan ge administratörsbehörighet.',
    'remove_group_memberships' => 'Ta bort gruppmedlemskap',
    'warning_deletion_information' => 'Du är på väg att checka in ALLA objekt från :count användare som anges nedan. Huvudanvändares namn markeras i rött.',
    'update_user_assets_status' => 'Uppdatera alla tillgångar för dessa användare till denna status',
    'checkin_user_properties' => 'Checka in alla egenskaper som är associerade med dessa användare',
    'remote_label'   => 'Detta är en fjärranvändare',
    'remote'   => 'Distansarbete',
    'remote_help' => 'Detta kan vara användbart om du behöver filtrera användare som arbetar på distans som aldrig eller sällan besöker dina fysiska platser.',
    'not_remote_label' => 'Detta är inte en distansanvändare',
    'vip_label' => 'VIP-användare',
    'vip_help' => 'Detta kan vara till hjälp för att markera viktiga personer i din organisation om du vill hantera dem på speciella sätt.',
    'create_user' => 'Skapa en användare',
    'create_user_page_explanation' => 'Detta är den kontoinformation du kommer att använda för att komma åt webbplatsen för första gången.',
    'email_credentials' => 'E-postuppgifter',
    'email_credentials_text' => 'E-posta mina uppgifter till e-postadressen ovan',
    'next_save_user' => 'Nästa: Spara användare',
    'all_assigned_list_generation' => 'Skapad:',
    'email_user_creds_on_create' => 'E-posta den här användaren sina inloggningsuppgifter?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/sv-SE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Den här användaren kan logga in',
    'activated_disabled_help_text' => 'Du kan inte redigera aktiveringsstatus för ditt eget konto.',
    'assets_user'       => 'Tillgångar tilldelade :name',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos :user_count användare. Observera att du inte kan ändra dina egna användarattribut med hjälp av det här formuläret utan du måste göra ändringar till din egen användare enskilt.',
    'bulk_update_help'	=> 'Det här formuläret låter dig uppdatera flera användare samtidigt. Fyll i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'current_assets'    => 'Tillgångar utcheckade till denna användare',
    'clone'             => 'Kopiera användare',
    'contact_user'      => 'Kontakta :name',
    'edit'              => 'Redigera användare',
    'filetype_info'     => 'Tillåtna filtyper är png, gif, jpg, jpeg, doc, docx, pdf, txt, zip och rar.',
    'history_user'      => 'Historik för :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klicka här för att återställa dem.',
    'last_login'        => 'Senaste inloggning',
    'ldap_config_text'  => 'LDAP-konfigurationsinställningar återfinnes under Admin > Inställningar. Den (valfria) valda platsen kommer att ställas in för alla importerade användare.',
    'print_assigned'    => 'Skriv ut alla tilldelade',
    'email_assigned'    => 'E-postlista med alla tilldelade',
    'user_notified'     => 'Användaren har blivit e-postad med en lista över sina nuvarande tilldelade objekt.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Inkludera denna användare när du automatiskt tilldelar kvalificerade licenser',
    'auto_assign_help'  => 'Hoppa över denna användare i automatisk tilldelning av licenser',
    'software_user'     => 'Programvara utcheckad till :name',
    'view_user'         => 'Visa användare :name',
    'usercsv'           => 'CSV-fil',
    'two_factor_admin_optin_help' => 'Dina nuvarande administratörsinställningar tillåter selektiv tillämpning av tvåfaktorsautentisering.  ',
    'two_factor_enrolled' => '2FA-enhet konfigurerad ',
    'two_factor_active'   => '2FA aktiv ',
    'user_deactivated'  => 'Användaren kan inte logga in',
    'user_activated'  => 'Användaren kan logga in',
    'activation_status_warning' => 'Ändra inte aktiveringsstatus',
    'group_memberships_helpblock' => 'Endast huvudanvändare kan redigera gruppmedlemskap.',
    'superadmin_permission_warning' => 'Endast huvudanvändare kan ge en användare huvudanvändaråtkomst.',
    'admin_permission_warning' => 'Endast användare med administratörsrättigheter eller högre kan ge administratörsbehörighet.',
    'remove_group_memberships' => 'Ta bort gruppmedlemskap',
    'warning_deletion_information' => 'Du är på väg att checka in ALLA objekt från :count användare som anges nedan. Huvudanvändares namn markeras i rött.',
    'update_user_assets_status' => 'Uppdatera alla tillgångar för dessa användare till denna status',
    'checkin_user_properties' => 'Checka in alla egenskaper som är associerade med dessa användare',
    'remote_label'   => 'Detta är en fjärranvändare',
    'remote'   => 'Distansarbete',
    'remote_help' => 'Detta kan vara användbart om du behöver filtrera användare som arbetar på distans som aldrig eller sällan besöker dina fysiska platser.',
    'not_remote_label' => 'Detta är inte en distansanvändare',
    'vip_label' => 'VIP-användare',
    'vip_help' => 'Detta kan vara till hjälp för att markera viktiga personer i din organisation om du vill hantera dem på speciella sätt.',
    'create_user' => 'Skapa en användare',
    'create_user_page_explanation' => 'Detta är den kontoinformation du kommer att använda för att komma åt webbplatsen för första gången.',
    'email_credentials' => 'E-postuppgifter',
    'email_credentials_text' => 'E-posta mina uppgifter till e-postadressen ovan',
    'next_save_user' => 'Nästa: Spara användare',
    'all_assigned_list_generation' => 'Skapad:',
    'email_user_creds_on_create' => 'E-posta den här användaren sina inloggningsuppgifter?',
    'department_manager' => 'Department Manager',
];
